aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/acl.erl26
-rw-r--r--src/adhoc.erl20
-rw-r--r--src/configure.erl26
-rw-r--r--src/cyrsasl.erl26
-rw-r--r--src/cyrsasl_anonymous.erl23
-rw-r--r--src/cyrsasl_plain.erl26
-rw-r--r--src/ejabberd.erl28
-rw-r--r--src/ejabberd_admin.erl25
-rw-r--r--src/ejabberd_app.erl28
-rw-r--r--src/ejabberd_auth.erl28
-rw-r--r--src/ejabberd_auth_anonymous.erl20
-rw-r--r--src/ejabberd_auth_external.erl26
-rw-r--r--src/ejabberd_auth_internal.erl26
-rw-r--r--src/ejabberd_auth_ldap.erl26
-rw-r--r--src/ejabberd_auth_odbc.erl26
-rw-r--r--src/ejabberd_auth_pam.erl20
-rw-r--r--src/ejabberd_c2s.erl26
-rw-r--r--src/ejabberd_c2s_config.erl20
-rw-r--r--src/ejabberd_config.erl25
-rw-r--r--src/ejabberd_ctl.erl26
-rw-r--r--src/ejabberd_frontend_socket.erl22
-rw-r--r--src/ejabberd_hooks.erl26
-rw-r--r--src/ejabberd_listener.erl28
-rw-r--r--src/ejabberd_local.erl26
-rw-r--r--src/ejabberd_logger_h.erl27
-rw-r--r--src/ejabberd_loglevel.erl20
-rw-r--r--src/ejabberd_node_groups.erl20
-rw-r--r--src/ejabberd_rdbms.erl24
-rw-r--r--src/ejabberd_receiver.erl26
-rw-r--r--src/ejabberd_router.erl26
-rw-r--r--src/ejabberd_s2s.erl26
-rw-r--r--src/ejabberd_s2s_in.erl26
-rw-r--r--src/ejabberd_s2s_out.erl19
-rw-r--r--src/ejabberd_service.erl28
-rw-r--r--src/ejabberd_sm.erl25
-rw-r--r--src/ejabberd_socket.erl22
-rw-r--r--src/ejabberd_sup.erl28
-rw-r--r--src/ejabberd_system_monitor.erl20
-rw-r--r--src/ejabberd_tmp_sup.erl26
-rw-r--r--src/ejabberd_update.erl28
-rw-r--r--src/ejd2odbc.erl26
-rw-r--r--src/extauth.erl20
-rw-r--r--src/gen_iq_handler.erl26
-rw-r--r--src/gen_mod.erl25
-rw-r--r--src/idna.erl26
-rw-r--r--src/jd2ejd.erl26
-rw-r--r--src/jlib.erl28
-rw-r--r--src/mod_adhoc.erl20
-rw-r--r--src/mod_announce.erl29
-rw-r--r--src/mod_caps.erl19
-rw-r--r--src/mod_configure.erl29
-rw-r--r--src/mod_configure2.erl26
-rw-r--r--src/mod_disco.erl26
-rw-r--r--src/web/ejabberd_web_admin.erl26
54 files changed, 1156 insertions, 186 deletions
diff --git a/src/adhoc.erl b/src/adhoc.erl
index 2f8ad2283..11fc17730 100644
--- a/src/adhoc.erl
+++ b/src/adhoc.erl
@@ -3,7 +3,25 @@
%%% Author : Magnus Henoch <henoch@dtek.chalmers.se>
%%% Purpose : Provide helper functions for ad-hoc commands (JEP-0050)
%%% Created : 31 Oct 2005 by Magnus Henoch <henoch@dtek.chalmers.se>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(adhoc).
diff --git a/src/cyrsasl_anonymous.erl b/src/cyrsasl_anonymous.erl
index 932a8ad2b..fe3c62132 100644
--- a/src/cyrsasl_anonymous.erl
+++ b/src/cyrsasl_anonymous.erl
@@ -2,12 +2,29 @@
%%% File : cyrsasl_anonymous.erl
%%% Author : Magnus Henoch <henoch@dtek.chalmers.se>
%%% Purpose : ANONYMOUS SASL mechanism
+%%% See http://www.ietf.org/internet-drafts/draft-ietf-sasl-anon-05.txt
%%% Created : 23 Aug 2005 by Magnus Henoch <henoch@dtek.chalmers.se>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-%% See http://www.ietf.org/internet-drafts/draft-ietf-sasl-anon-05.txt
-
-module(cyrsasl_anonymous).
-export([start/1, stop/0, mech_new/3, mech_step/2]).
diff --git a/src/ejabberd.erl b/src/ejabberd.erl
index 1c586e50f..b24b3ca49 100644
--- a/src/ejabberd.erl
+++ b/src/ejabberd.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 16 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : ejabberd wrapper: start / stop
+%%% Created : 16 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0, stop/0,
get_so_path/0]).
diff --git a/src/ejabberd_admin.erl b/src/ejabberd_admin.erl
index 6421fef10..8817bc8ed 100644
--- a/src/ejabberd_admin.erl
+++ b/src/ejabberd_admin.erl
@@ -1,4 +1,4 @@
-%%%-------------------------------------------------------------------
+$%%%-------------------------------------------------------------------
%%% File : ejabberd_admin.erl
%%% Author : Mickael Remond <mremond@process-one.net>
%%% Description : This module gathers admin functions used by different
@@ -6,11 +6,26 @@
%%% - ejabberdctl command-line tool
%%% - web admin interface
%%% - adhoc mode
-%%%
%%% Created : 7 May 2006 by Mickael Remond <mremond@process-one.net>
-%%% Id : $Id$
-%%%----------------------------------------------------------------------
-%%% Copyright (c) 2006-2007 Process One
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%-------------------------------------------------------------------
-module(ejabberd_admin).
diff --git a/src/ejabberd_app.erl b/src/ejabberd_app.erl
index ef04ad836..f8df5efe4 100644
--- a/src/ejabberd_app.erl
+++ b/src/ejabberd_app.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_app.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 31 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : ejabberd OTP application definition.
+%%% Created : 31 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_app).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(application).
diff --git a/src/ejabberd_auth_anonymous.erl b/src/ejabberd_auth_anonymous.erl
index 43cb15518..255b35190 100644
--- a/src/ejabberd_auth_anonymous.erl
+++ b/src/ejabberd_auth_anonymous.erl
@@ -4,10 +4,24 @@
%%% Purpose : Anonymous feature support in ejabberd
%%% Created : 17 Feb 2006 by Mickael Remond <mremond@process-one.net>
%%%
-%%% Anonymous support is based on the work of Magnus Henoch
-%%% <henoch@dtek.chalmers.se> and heavily extended by Process-one.
%%%
-%%% Id : $Id$
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_auth_anonymous).
diff --git a/src/ejabberd_auth_pam.erl b/src/ejabberd_auth_pam.erl
index e420313e7..8fe3277c9 100644
--- a/src/ejabberd_auth_pam.erl
+++ b/src/ejabberd_auth_pam.erl
@@ -3,7 +3,25 @@
%%% Author : Evgeniy Khramtsov <xram@jabber.ru>
%%% Purpose : PAM authentication
%%% Created : 5 Jul 2007 by Evgeniy Khramtsov <xram@jabber.ru>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%-------------------------------------------------------------------
-module(ejabberd_auth_pam).
-author('xram@jabber.ru').
diff --git a/src/ejabberd_c2s_config.erl b/src/ejabberd_c2s_config.erl
index 1614c47bf..6609bc147 100644
--- a/src/ejabberd_c2s_config.erl
+++ b/src/ejabberd_c2s_config.erl
@@ -4,7 +4,25 @@
%%% Purpose : Functions for c2s interactions from other client
%%% connector modules
%%% Created : 2 Nov 2007 by Mickael Remond <mremond@process-one.net>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_c2s_config).
diff --git a/src/ejabberd_frontend_socket.erl b/src/ejabberd_frontend_socket.erl
index 09f75dfdc..f889f7d0b 100644
--- a/src/ejabberd_frontend_socket.erl
+++ b/src/ejabberd_frontend_socket.erl
@@ -2,8 +2,26 @@
%%% File : ejabberd_frontend_socket.erl
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Frontend socket with zlib and TLS support library
-%%% Created : 23 Aug 2006 by Alexey Shchepin <alex@alex.sevcom.net>
-%%% Id : $Id$
+%%% Created : 23 Aug 2006 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_frontend_socket).
diff --git a/src/ejabberd_listener.erl b/src/ejabberd_listener.erl
index 808896e20..f2498c2d3 100644
--- a/src/ejabberd_listener.erl
+++ b/src/ejabberd_listener.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_listener.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 16 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Manage socket listener
+%%% Created : 16 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_listener).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start_link/0, init/1, start/3,
init/3,
diff --git a/src/ejabberd_logger_h.erl b/src/ejabberd_logger_h.erl
index e5fe0f3a9..c3f6586e0 100644
--- a/src/ejabberd_logger_h.erl
+++ b/src/ejabberd_logger_h.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_logger_h.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 23 Oct 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Manage Erlang logging.
+%%% Created : 23 Oct 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_logger_h).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_event).
diff --git a/src/ejabberd_loglevel.erl b/src/ejabberd_loglevel.erl
index f9eddda40..018d9ab41 100644
--- a/src/ejabberd_loglevel.erl
+++ b/src/ejabberd_loglevel.erl
@@ -7,7 +7,27 @@
%%% dynamically a "virtual" ejabberd_logger module (Described
%%% in a string at the end of this module).
%%% Created : 29 Nov 2006 by Mickael Remond <mremond@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
+
-module(ejabberd_loglevel).
-author('mickael.remond@process-one.net').
diff --git a/src/ejabberd_node_groups.erl b/src/ejabberd_node_groups.erl
index e36d429a2..b3521362a 100644
--- a/src/ejabberd_node_groups.erl
+++ b/src/ejabberd_node_groups.erl
@@ -3,7 +3,25 @@
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Distributed named node groups based on pg2 module
%%% Created : 1 Nov 2006 by Alexey Shchepin <alexey@process-one.net>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_node_groups).
diff --git a/src/ejabberd_rdbms.erl b/src/ejabberd_rdbms.erl
index 10fb6021b..155653c1f 100644
--- a/src/ejabberd_rdbms.erl
+++ b/src/ejabberd_rdbms.erl
@@ -2,12 +2,30 @@
%%% File : ejabberd_rdbms.erl
%%% Author : Mickael Remond <mickael.remond@process-one.net>
%%% Purpose : Manage the start of the database modules when needed
-%%% Created : 31 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 31 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_rdbms).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0]).
-include("ejabberd.hrl").
diff --git a/src/ejabberd_s2s_out.erl b/src/ejabberd_s2s_out.erl
index b186f2b7f..c8094f8f9 100644
--- a/src/ejabberd_s2s_out.erl
+++ b/src/ejabberd_s2s_out.erl
@@ -3,6 +3,25 @@
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Manage outgoing server-to-server connections
%%% Created : 6 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_s2s_out).
diff --git a/src/ejabberd_service.erl b/src/ejabberd_service.erl
index 520a3720e..51c5b3e0c 100644
--- a/src/ejabberd_service.erl
+++ b/src/ejabberd_service.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_service.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 6 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : External component management
+%%% Created : 6 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_service).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_fsm).
diff --git a/src/ejabberd_socket.erl b/src/ejabberd_socket.erl
index 884483d56..1c298293b 100644
--- a/src/ejabberd_socket.erl
+++ b/src/ejabberd_socket.erl
@@ -2,8 +2,26 @@
%%% File : ejabberd_socket.erl
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Socket with zlib and TLS support library
-%%% Created : 23 Aug 2006 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 23 Aug 2006 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_socket).
diff --git a/src/ejabberd_sup.erl b/src/ejabberd_sup.erl
index 88a636776..b23aa8dc1 100644
--- a/src/ejabberd_sup.erl
+++ b/src/ejabberd_sup.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_sup.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 31 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : Erlang/OTP supervisor
+%%% Created : 31 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_sup).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(supervisor).
diff --git a/src/ejabberd_system_monitor.erl b/src/ejabberd_system_monitor.erl
index 104b7f821..d27e8151b 100644
--- a/src/ejabberd_system_monitor.erl
+++ b/src/ejabberd_system_monitor.erl
@@ -3,7 +3,25 @@
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Description : Ejabberd watchdog
%%% Created : 21 Mar 2007 by Alexey Shchepin <alexey@process-one.net>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%-------------------------------------------------------------------
-module(ejabberd_system_monitor).
diff --git a/src/ejabberd_update.erl b/src/ejabberd_update.erl
index 71f97f049..257e78917 100644
--- a/src/ejabberd_update.erl
+++ b/src/ejabberd_update.erl
@@ -1,13 +1,31 @@
%%%-------------------------------------------------------------------
%%% File : ejabberd_update.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose : Update ejabberd
-%%% Created : 27 Jan 2006 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : ejabberd code updater
+%%% Created : 27 Jan 2006 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%-------------------------------------------------------------------
-module(ejabberd_update).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% API
-export([update/0, update_info/0]).
diff --git a/src/extauth.erl b/src/extauth.erl
index 80f55c596..4bbce2fcf 100644
--- a/src/extauth.erl
+++ b/src/extauth.erl
@@ -3,7 +3,25 @@
%%% Author : Leif Johansson <leifj@it.su.se>
%%% Purpose : External authentication using a simple port-driver
%%% Created : 30 Jul 2004 by Leif Johansson <leifj@it.su.se>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(extauth).
diff --git a/src/jlib.erl b/src/jlib.erl
index 98864471a..620b71c95 100644
--- a/src/jlib.erl
+++ b/src/jlib.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : jlib.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
-%%% Purpose :
-%%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Author : Alexey Shchepin <alexey@process-one.net>
+%%% Purpose : General XMPP library.
+%%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(jlib).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([make_result_iq_reply/1,
make_error_reply/3,
diff --git a/src/mod_adhoc.erl b/src/mod_adhoc.erl
index 4b8004872..97670bdf4 100644
--- a/src/mod_adhoc.erl
+++ b/src/mod_adhoc.erl
@@ -3,7 +3,25 @@
%%% Author : Magnus Henoch <henoch@dtek.chalmers.se>
%%% Purpose : Handle incoming ad-doc requests (JEP-0050)
%%% Created : 15 Nov 2005 by Magnus Henoch <henoch@dtek.chalmers.se>
-%%% Id : $Id$
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_adhoc).
diff --git a/src/mod_caps.erl b/src/mod_caps.erl
index d341677ee..1bec88817 100644
--- a/src/mod_caps.erl
+++ b/src/mod_caps.erl
@@ -3,6 +3,25 @@
%%% Author : Magnus Henoch <henoch@dtek.chalmers.se>
%%% Purpose : Request and cache Entity Capabilities (XEP-0115)
%%% Created : 7 Oct 2006 by Magnus Henoch <henoch@dtek.chalmers.se>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_caps).
diff --git a/src/web/ejabberd_web_admin.erl b/src/web/ejabberd_web_admin.erl
index 4a61f332a..cbec6e4d0 100644
--- a/src/web/ejabberd_web_admin.erl
+++ b/src/web/ejabberd_web_admin.erl
@@ -3,9 +3,25 @@
%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Administration web interface
%%% Created : 9 Apr 2004 by Alexey Shchepin <alexey@process-one.net>
-%%%----------------------------------------------------------------------
-%%% Copyright (c) 2004-2007 Alexey Shchepin
-%%% Copyright (c) 2004-2007 Process One
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_web_admin).
@@ -134,7 +150,7 @@ make_xhtml(Els, global, Lang) ->
[?XAE("div",
[{"id", "copyright"}],
[?XC("p",
- "ejabberd (c) 2002-2007 Alexey Shchepin, 2004-2007 Process One")
+ "ejabberd (c) 2002-2007 ProcessOne")
])])])
]}};
@@ -191,7 +207,7 @@ make_xhtml(Els, Host, Lang) ->
[?XAE("div",
[{"id", "copyright"}],
[?XC("p",
- "ejabberd (c) 2002-2007 Alexey Shchepin, 2004-2007 Process One")
+ "ejabberd (c) 2002-2007 ProcessOne")
])])])
]}}.
diff --git a/src/acl.erl b/src/acl.erl
index 760de2f26..efeffe65a 100644
--- a/src/acl.erl
+++ b/src/acl.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : acl.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : ACL support
-%%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 18 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(acl).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0,
to_record/3,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : acl.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : ACL support
diff --git a/src/configure.erl b/src/configure.erl
index fd1d9756f..89f452dc0 100644
--- a/src/configure.erl
+++ b/src/configure.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : configure.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose :
-%%% Created : 27 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 27 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(configure).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0]).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : configure.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose :
diff --git a/src/cyrsasl.erl b/src/cyrsasl.erl
index 73b5eb37c..e91d917af 100644
--- a/src/cyrsasl.erl
+++ b/src/cyrsasl.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : cyrsasl.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Cyrus SASL-like library
-%%% Created : 8 Mar 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 8 Mar 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(cyrsasl).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0,
register_mechanism/3,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : cyrsasl.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Cyrus SASL-like library
diff --git a/src/cyrsasl_plain.erl b/src/cyrsasl_plain.erl
index b6e7fafe5..e200be016 100644
--- a/src/cyrsasl_plain.erl
+++ b/src/cyrsasl_plain.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : cyrsasl_plain.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : PLAIN SASL mechanism
-%%% Created : 8 Mar 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 8 Mar 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(cyrsasl_plain).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/1, stop/0, mech_new/3, mech_step/2, parse/1]).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : cyrsasl_plain.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : PLAIN SASL mechanism
diff --git a/src/ejabberd_auth.erl b/src/ejabberd_auth.erl
index 37145f5d9..d2f799672 100644
--- a/src/ejabberd_auth.erl
+++ b/src/ejabberd_auth.erl
@@ -1,17 +1,33 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Authentification
-%%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Updated : 23 Feb 2006 by Mickael Remond <mremond@process-one.net>
-%%% for anonymous login support
-%%% Id : $Id$
+%%% Created : 23 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
%% TODO: Use the functions in ejabberd auth to add and remove users.
-module(ejabberd_auth).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([start/0,
@@ -1,17 +1,33 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Authentification
diff --git a/src/ejabberd_auth_external.erl b/src/ejabberd_auth_external.erl
index b0c4f1233..c3ad0260c 100644
--- a/src/ejabberd_auth_external.erl
+++ b/src/ejabberd_auth_external.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_external.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Authentification via LDAP external script
-%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_auth_external).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([start/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_external.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Authentification via LDAP external script
diff --git a/src/ejabberd_auth_internal.erl b/src/ejabberd_auth_internal.erl
index 289972b75..9f5472d24 100644
--- a/src/ejabberd_auth_internal.erl
+++ b/src/ejabberd_auth_internal.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_internal.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Authentification via mnesia
-%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_auth_internal).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([start/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_internal.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Authentification via mnesia
diff --git a/src/ejabberd_auth_ldap.erl b/src/ejabberd_auth_ldap.erl
index ecb0bb753..c89dc62d3 100644
--- a/src/ejabberd_auth_ldap.erl
+++ b/src/ejabberd_auth_ldap.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_ldap.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Authentification via LDAP
-%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_auth_ldap).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_ldap.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Authentification via LDAP
diff --git a/src/ejabberd_auth_odbc.erl b/src/ejabberd_auth_odbc.erl
index 7ec42a3cc..910a2020f 100644
--- a/src/ejabberd_auth_odbc.erl
+++ b/src/ejabberd_auth_odbc.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Authentification via ODBC
-%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 12 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_auth_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([start/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_auth_odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Authentification via ODBC
diff --git a/src/ejabberd_c2s.erl b/src/ejabberd_c2s.erl
index 8a449a8c8..7d1561c41 100644
--- a/src/ejabberd_c2s.erl
+++ b/src/ejabberd_c2s.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_c2s.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Serve C2S connection
-%%% Created : 16 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 16 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_c2s).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-update_info({update, 0}).
-behaviour(gen_fsm).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_c2s.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Serve C2S connection
diff --git a/src/ejabberd_config.erl b/src/ejabberd_config.erl
index 41cb7f9d1..350b78250 100644
--- a/src/ejabberd_config.erl
+++ b/src/ejabberd_config.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_config.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Load config file
-%%% Created : 14 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 14 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_config).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0, load_file/1,
add_global_option/2, add_local_option/2,
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_config.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Load config file
diff --git a/src/ejabberd_ctl.erl b/src/ejabberd_ctl.erl
index 612daab4c..c0c25e4e1 100644
--- a/src/ejabberd_ctl.erl
+++ b/src/ejabberd_ctl.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_ctl.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Ejabberd admin tool
-%%% Created : 11 Jan 2004 by Alexey Shchepin <alex@alex.sevcom.net>
-%%% Id : $Id$
+%%% Created : 11 Jan 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_ctl).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0,
init/0,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_ctl.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Ejabberd admin tool
diff --git a/src/ejabberd_hooks.erl b/src/ejabberd_hooks.erl
index 9916876be..53540607d 100644
--- a/src/ejabberd_hooks.erl
+++ b/src/ejabberd_hooks.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_hooks.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Manage hooks
-%%% Created : 8 Aug 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 8 Aug 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_hooks).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_hooks.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Manage hooks
diff --git a/src/ejabberd_local.erl b/src/ejabberd_local.erl
index a7ef092b4..4590cdf05 100644
--- a/src/ejabberd_local.erl
+++ b/src/ejabberd_local.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_local.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Route local packets
-%%% Created : 30 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 30 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_local).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_local.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Route local packets
diff --git a/src/ejabberd_receiver.erl b/src/ejabberd_receiver.erl
index a017a141d..1e280378c 100644
--- a/src/ejabberd_receiver.erl
+++ b/src/ejabberd_receiver.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_receiver.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Socket receiver for C2S and S2S connections
-%%% Created : 10 Nov 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 10 Nov 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_receiver).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_receiver.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Socket receiver for C2S and S2S connections
diff --git a/src/ejabberd_router.erl b/src/ejabberd_router.erl
index 25ca3b40c..4623c36c6 100644
--- a/src/ejabberd_router.erl
+++ b/src/ejabberd_router.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_router.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Main router
-%%% Created : 27 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 27 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_router).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_router.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Main router
diff --git a/src/ejabberd_s2s.erl b/src/ejabberd_s2s.erl
index f6ffb577a..0aae81319 100644
--- a/src/ejabberd_s2s.erl
+++ b/src/ejabberd_s2s.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_s2s.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : S2S connections manager
-%%% Created : 7 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 7 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_s2s).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_s2s.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : S2S connections manager
diff --git a/src/ejabberd_s2s_in.erl b/src/ejabberd_s2s_in.erl
index d163220d5..8527ec2b1 100644
--- a/src/ejabberd_s2s_in.erl
+++ b/src/ejabberd_s2s_in.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_s2s_in.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Serve incoming s2s connection
-%%% Created : 6 Dec 2002 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 6 Dec 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_s2s_in).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_fsm).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_s2s_in.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Serve incoming s2s connection
diff --git a/src/ejabberd_sm.erl b/src/ejabberd_sm.erl
index 025b6de68..ff4a25d4f 100644
--- a/src/ejabberd_sm.erl
+++ b/src/ejabberd_sm.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_sm.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Session manager
-%%% Created : 24 Nov 2002 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 24 Nov 2002 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_sm).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_sm.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Session manager
diff --git a/src/ejabberd_tmp_sup.erl b/src/ejabberd_tmp_sup.erl
index 4b1a4d9e5..fafd4611f 100644
--- a/src/ejabberd_tmp_sup.erl
+++ b/src/ejabberd_tmp_sup.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_tmp_sup.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Supervisor for temporary processess
-%%% Created : 18 Jul 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 18 Jul 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_tmp_sup).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start_link/2, init/1]).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_tmp_sup.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Supervisor for temporary processess
diff --git a/src/ejd2odbc.erl b/src/ejd2odbc.erl
index 122edde00..da718b8ae 100644
--- a/src/ejd2odbc.erl
+++ b/src/ejd2odbc.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejd2odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Export some mnesia tables to SQL DB
-%%% Created : 22 Aug 2005 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 22 Aug 2005 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejd2odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([export_passwd/2,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejd2odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Export some mnesia tables to SQL DB
diff --git a/src/gen_iq_handler.erl b/src/gen_iq_handler.erl
index ae6ba0f77..fc9339d95 100644
--- a/src/gen_iq_handler.erl
+++ b/src/gen_iq_handler.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : gen_iq_handler.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : IQ handler support
-%%% Created : 22 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 22 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(gen_iq_handler).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : gen_iq_handler.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : IQ handler support
diff --git a/src/gen_mod.erl b/src/gen_mod.erl
index 22a2254a6..388dd0d9f 100644
--- a/src/gen_mod.erl
+++ b/src/gen_mod.erl
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : gen_mod.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose :
-%%% Created : 24 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
+%%% Created : 24 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(gen_mod).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-export([start/0,
start_module/3,
@@ -1,12 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : gen_mod.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose :
diff --git a/src/idna.erl b/src/idna.erl
index 23e13deb3..f63718e8e 100644
--- a/src/idna.erl
+++ b/src/idna.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : idna.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Support for IDNA (RFC3490)
-%%% Created : 10 Apr 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 10 Apr 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(idna).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%%-compile(export_all).
-export([domain_utf8_to_ascii/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : idna.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Support for IDNA (RFC3490)
diff --git a/src/jd2ejd.erl b/src/jd2ejd.erl
index 28c6303da..904c73662 100644
--- a/src/jd2ejd.erl
+++ b/src/jd2ejd.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : jd2ejd.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Import of jabberd1.4 user spool file
-%%% Created : 2 Feb 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 2 Feb 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(jd2ejd).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% External exports
-export([import_file/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : jd2ejd.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Import of jabberd1.4 user spool file
diff --git a/src/mod_announce.erl b/src/mod_announce.erl
index 7579cfaf0..7ed511619 100644
--- a/src/mod_announce.erl
+++ b/src/mod_announce.erl
@@ -1,15 +1,34 @@
%%%----------------------------------------------------------------------
%%% File : mod_announce.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Manage announce messages
-%%% Created : 11 Aug 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 11 Aug 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-%%% Implements a small subset of XEP-0133: Service Administration Version 1.1 (2005-08-19)
+%%% Implements a small subset of XEP-0133: Service Administration
+%%% Version 1.1 (2005-08-19)
-module(mod_announce).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,15 +1,34 @@
%%%----------------------------------------------------------------------
%%% File : mod_announce.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Manage announce messages
diff --git a/src/mod_configure.erl b/src/mod_configure.erl
index 8f4a10290..cbf3f1d71 100644
--- a/src/mod_configure.erl
+++ b/src/mod_configure.erl
@@ -1,15 +1,34 @@
%%%----------------------------------------------------------------------
%%% File : mod_configure.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Support for online configuration of ejabberd
-%%% Created : 19 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 19 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-%%% Implements most of XEP-0133: Service Administration Version 1.1 (2005-08-19)
+%%% Implements most of XEP-0133: Service Administration Version 1.1
+%%% (2005-08-19)
-module(mod_configure).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,15 +1,34 @@
%%%----------------------------------------------------------------------
%%% File : mod_configure.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Support for online configuration of ejabberd
diff --git a/src/mod_configure2.erl b/src/mod_configure2.erl
index 74f04c1c4..ab6ce45a8 100644
--- a/src/mod_configure2.erl
+++ b/src/mod_configure2.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_configure2.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Support for online configuration of ejabberd
-%%% Created : 26 Oct 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 26 Oct 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_configure2).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_configure2.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Support for online configuration of ejabberd
diff --git a/src/mod_disco.erl b/src/mod_disco.erl
index 937d5e9ec..6514a168c 100644
--- a/src/mod_disco.erl
+++ b/src/mod_disco.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_disco.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Service Discovery (JEP-0030) support
-%%% Created : 1 Jan 2003 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 1 Jan 2003 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(mod_disco).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_mod).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : mod_disco.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Service Discovery (JEP-0030) support